% Function returns, in [m/s], the flow rate or the flow profile for a rectangular 
% cross section microchannel. See Book, Theoretical Microfluidics by Henrik
% Bruus for details.
% If y and z are scalars, output is scalar. 
% If y or z is a vector, output is a vector
% If y and z are vectors, output is a matrix
% ymin = 0, ymax = W, zmin = 0, zmax = H
% flowRate in m^3/s
% w is channel width [m]
% h is channel height [m]
% N is number of summations to carry out. (7 is normally good)
%
% Author: Per Augustsson
%
% Last edited: 2014-12-09

function vx = poiseuille(flowRate, w, h, N, y, z)

% Alloocate matirix
vx = zeros(length(z),length(y));

% Transpose coordinate system
y = y - w/2;

% N must be an odd number. Check, adjust and alert if not
if mod(N,2) == 0
    N=N+1;
    disp(['N must be odd, adjusting to N = ' num2str(N)]);
end

for j=1:length(z)
    for i=1:length(y)
        A=0; %numerator
        B=0; %denominator
        for n = 1:2:N
            A = A + flowRate/n^3*(1 - cosh(n*pi*y(1,i)/h)/cosh(n*pi*w/2/h))*sin(n*pi*z(1,j)/h);
            B = B + 1/n^4*2*h/pi*(w - 2*h/n/pi*tanh(n*pi*w/2/h));
        end
        vx(j,i) = A/B;
    end
end
